@@ -3,12 +3,12 @@ use strict;
 use warnings;
 use GStreamer -init;
 
-# $Id: elementfactory.pl,v 1.1 2005/03/23 20:46:46 kaffeetisch Exp $
+# $Id: elementfactory.pl,v 1.2 2005/12/03 00:28:13 kaffeetisch Exp $
 
 # get factory
-my $factory = GStreamer::ElementFactory -> find("sinesrc");
+my $factory = GStreamer::ElementFactory -> find("audiotestsrc");
 unless ($factory) {
-  print "You don't have the 'sinesrc' element installed, go get it!\n";
+  print "You don't have the 'audiotestsrc' element installed, go get it!\n";
   exit -1;
 }
 
